# -*- coding: utf-8 -*-
#COPYRIGHT 2019 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Business Analyst toolbox contains sets of tools that perform GIS
operations fundamental to market analysis. With the tools in this
toolbox, you can perform demographic reporting, review customer and
competitor distributions, identify key trade areas, and visualize data
variables."""
__all__ = ['AddFieldBasedSuitabilityCriteria',
           'AddPointLayerBasedSuitabilityCriteria',
           'AddVariableBasedSuitabilityCriteria', 'CalculateMarketPenetration',
           'CalculateSuitabilityScore', 'ColorCodedLayer', 'CustomerDerivedTA',
           'DesireLines', 'EnrichLayer', 'GenerateDriveTimeTradeArea',
           'GenerateGeographiesFromOverlay',
           'GeneratePointsFromBusinessListings', 'GenerateTradeAreaRings',
           'HuffModel', 'MakeSuitabilityAnalysisLayer',
           'RemoveSuitabilityCriteria', 'SetCriteriaProperties',
           'StandardGeographyTA', 'SummaryReports']
__alias__ = 'ba'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analysis toolset
@gptooldoc('CalculateMarketPenetration_ba', None)
def CalculateMarketPenetration(in_features=None, out_feature_class=None, id_field=None, market_penetration_base_field=None, in_customer_features=None, area_description_field=None, weight_field=None, create_report=None, store_id=None, link_field=None, report_title=None, report_folder=None, report_format=None):
    """CalculateMarketPenetration_ba(in_features, out_feature_class, id_field, market_penetration_base_field, in_customer_features, {area_description_field}, {weight_field}, {create_report}, {store_id}, {link_field}, {report_title}, {report_folder}, {report_format;report_format...})

        Calculates the market penetration based on the number of customers
        within an area compared to a demographic variable such as total
        population. You can also calculate market penetration based on a
        weight field in
        the customer layer rather than customer counts-for example, you can
        calculate penetration based on total sales per household for each ZIP
        Code.

     INPUTS:
      in_features (Feature Layer):
          The input feature class used for calculating market penetration.
      id_field (Field):
          A unique ID field in the market penetration layer.
      market_penetration_base_field (Field):
          The field containing the values used to calculate market penetration.
          This field will be used as the denominator and represents your
          market-for example, Total Population or Total Households.
      in_customer_features (Feature Layer):
          The input feature class containing the points for the customer layer.
      area_description_field {Field}:
          The field used to describe each feature in the market penetration
          layer.
      weight_field {Field}:
          The field in the customer layer used as a weight to calculate market
          penetration rather than customer counts.
      create_report {Boolean}:
          Specifies whether a summary report will be created per boundary or by
          combining reports into a single report file.

          * CREATE_REPORT-A summary report will be created.

          * DO_NOT_CREATE_REPORT-A summary report will not be created. This is
          the default.
      store_id {Field}:
          A unique identifier associated with each store for each trade area.
      link_field {Field}:
          An ID that assigns a trade area to a customer.
      report_title {String}:
          The title of the report.
      report_folder {Folder}:
          The output directory that will contain the report.
      report_format {String}:
          Specifies one or more output report formats. The default value is
          PDF.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class that contains the calculated market
          penetration features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateMarketPenetration_ba(*gp_fixargs((in_features, out_feature_class, id_field, market_penetration_base_field, in_customer_features, area_description_field, weight_field, create_report, store_id, link_field, report_title, report_folder, report_format), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ColorCodedLayer_ba', None)
def ColorCodedLayer(classification_variable=None, out_layer_name=None, classification_method=None, number_of_classes=None):
    """ColorCodedLayer_ba(classification_variable, out_layer_name, classification_method, number_of_classes)

        Creates a multigeography-level, scale-dependent choropleth layer from
        a variable describing a business, demographic, consumer, or landscape
        characteristic.

     INPUTS:
      classification_variable (String):
          Select one variable to display as a color-coded map.
      out_layer_name (String):
          The name of the color-coded layer that will be added to the map.
      classification_method (String):
          The method that will be used to calculate the class breaks.

          * NATURAL_BREAKS-Natural breaks classes are based on natural groupings
          inherent in the data. Class breaks are identified that best group
          similar values and that maximize the differences between classes. This
          is the default.

          * QUANTILE-Each class contains an equal number of features. A quantile
          classification is well suited to linearly distributed data.

          * EQUAL_INTERVAL-Divides the range of attribute values into equal-
          sized subranges. This allows you to specify the number of intervals,
          and ArcGIS Pro will automatically determine the class breaks based on
          the value range.

          * GEOMETRIC_INTERVAL-Creates class breaks based on class intervals
          that have a geometric series. The geometric coefficient in this
          classifier can change once (to its inverse) to optimize the class
          ranges.
      number_of_classes (String):
          The number of data classification breaks that appear on the map. The
          default value is 5."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ColorCodedLayer_ba(*gp_fixargs((classification_variable, out_layer_name, classification_method, number_of_classes), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DesireLines_ba', None)
def DesireLines(in_stores_layer=None, in_customers_layer=None, out_feature_class=None, store_id_field=None, link_field=None, distance_type=None, units=None, cutoff=None, travel_direction=None, time_of_day=None, time_zone=None):
    """DesireLines_ba(in_stores_layer, in_customers_layer, out_feature_class, store_id_field, link_field, {distance_type}, {units}, {cutoff}, {travel_direction}, {time_of_day}, {time_zone})

        Creates a series of lines from each customer to an associated store
        location. These lines are often called spider diagrams.The tool output
        shows the spatial distribution between stores and
        customers and calculates the distance values between each store and
        customer.

     INPUTS:
      in_stores_layer (Feature Layer):
          Input point layer representing store or facility locations.
      in_customers_layer (Feature Layer):
          Input point layer representing customers or patrons.
      store_id_field (Field):
          Unique ID representing a store or facility location.
      link_field (Field):
          An ID used to assign individual customers to stores.
      distance_type {String}:
          Defines how distance is calculated based on method of travel.
      units {String}:
          Defines the type of distance- or time-measuring units to be used when
          calculating minimal distance.
      cutoff {Double}:
          The distance beyond which customers will be considered outliers and
          therefore, excluded from consideration during desire line creation.
      travel_direction {String}:
          Specifies whether to measure travel times or distances from stores to
          demand points or from demand points to stores.

          * TOWARD_STORES-Direction of travel is from stores to demand points.
          This is the default.

          * AWAY_FROM_STORES-Direction of travel is from demand points to
          stores.
      time_of_day {Date}:
          Specifies the time at which travel begins.
      time_zone {String}:
          Specifies the time zone of the Time of Day parameter.

          * UTC-The Time of Day parameter refers to coordinated universal time
          (UTC). Choose this option if you want to choose the best location for
          a specific time, such as now, but aren't certain in which time zone
          the stores or demand points will be located.

          * TIME_ZONE_AT_LOCATION-The Time of Day parameter refers to the time
          zone in which the stores or demand points are located. If Travel
          Direction is stores to demand points, this is the time zone of the
          stores. If Travel Direction is demand points to stores, this is the
          time zone of the demand points. This is the default.

     OUTPUTS:
      out_feature_class (Feature Class):
          The resultant feature class that will be added to the Contents pane."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DesireLines_ba(*gp_fixargs((in_stores_layer, in_customers_layer, out_feature_class, store_id_field, link_field, distance_type, units, cutoff, travel_direction, time_of_day, time_zone), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnrichLayer_ba', None)
def EnrichLayer(in_features=None, out_feature_class=None, variables=None, buffer_type=None, distance=None, unit=None):
    """EnrichLayer_ba(in_features, out_feature_class, {variables;variables...}, {buffer_type}, {distance}, {unit})

        Enriches data by adding demographic and landscape facts about the
        people and places that surround or are inside data locations. The
        output is a duplicate of the input with additional attribute fields.
        The demographic and landscape information available with this tool can
        come from ArcGIS Online or locally installed Business Analyst data.

        * Enrich Layer uses detailed aggregation and apportionment settings to
        summarize data.

        * This tool will consume credits if ArcGIS Online is set as the
        Business Analyst Data Source.

     INPUTS:
      in_features (Feature Layer):
          The features to be enriched.
      variables {String}:
          One or more variables to be summarized and added to the output feature
          class.
      buffer_type {String}:
          Input point features must have an associated boundary polygon to
          enrich. When connected to ArcGIS Online, travel mode options are
          dynamically populated. Input line features can only use Straight Line
          distance. The default value is Straight Line.
      distance {Double}:
          The distance or size of an area to enrich, for example, a 1-mile
          buffer or 5-minute walk time. Units correspond to the polygon type.
          The default value is 1.
      unit {String}:
          The units associated with the Distance or time parameter. The default
          value is Kilometers.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new layer containing both the input attributes and user-selected
          attributes. User-selected attributes are summarized from underlying
          demographic boundaries. Only the area inside the input boundary is
          considered."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnrichLayer_ba(*gp_fixargs((in_features, out_feature_class, variables, buffer_type, distance, unit), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeneratePointsFromBusinessListings_ba', None)
def GeneratePointsFromBusinessListings(out_feature_class=None, in_search_features=None, search_terms=None, exact_match=None, match_name_only=None, filters=None, max_count=None):
    """GeneratePointsFromBusinessListings_ba(out_feature_class, {in_search_features}, {search_terms}, {exact_match}, {match_name_only}, {filters;filters...}, {max_count})

        Creates a point feature layer from a business point location search.

     INPUTS:
      in_search_features {Feature Layer}:
          The area that will be used to search for businesses.
      search_terms {String}:
          The terms that will be used to search for businesses. You can use
          terms such as business name or business type keywords. If this
          parameter is not set, all businesses from the Input Search Features
          parameter will be returned.
      exact_match {Boolean}:
          Specifies whether only the text entered in the search_terms parameter
          will be returned from the search.

          * EXACT_MATCH-Only exact matches to the text entered in the
          search_terms parameter will be returned.

          * PARTIAL_MATCH-Partial matches to the text entered in the
          search_terms parameter will also be returned. This is the default.
      match_name_only {Boolean}:
          Specifies whether the search will be limited to the business name
          only.

          * MATCH_NAME_ONLY-Only exact matches to the business name entered in
          the search_terms parameter will be returned.

          * MATCH_ALL_FIELDS-Partial matches to the business name entered in the
          search_terms parameter will also be returned. This is the default.
      filters {Value Table}:
          Specifies the filters that will be applied to the search_terms
          parameter.

          * filter_name-Set filter by dataset field.

          * filter_value-Set filter by applying a value to the selected field.
          Filter values:

          * Min:Number

          * Max:Number

          * Min:Number Max:Number

          * include-Set filter by including or excluding field values. The
          default value is on.
      max_count {Long}:
          The limit for the number of returned features. The default value is
          1000000.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class that will contain the returned businesses."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeneratePointsFromBusinessListings_ba(*gp_fixargs((out_feature_class, in_search_features, search_terms, exact_match, match_name_only, filters, max_count), True)))
        return retval
    except Exception as e:
        raise e


# Modeling toolset
@gptooldoc('HuffModel_ba', None)
def HuffModel(in_facility_features=None, facility_id_field=None, in_candidate_features=None, candidate_id_field=None, in_sales_potential_features=None, sales_potential_id_field=None, sales_potential_field=None, out_feature_class=None, attractiveness_variables=None, distance_exponent=None, distance_type=None, distance_units=None, out_distance_matrix=None, travel_direction=None, time_of_day=None, time_zone=None):
    """HuffModel_ba(in_facility_features, facility_id_field, in_candidate_features, candidate_id_field, in_sales_potential_features, sales_potential_id_field, sales_potential_field, out_feature_class, attractiveness_variables;attractiveness_variables..., distance_exponent, {distance_type}, {distance_units}, {out_distance_matrix}, {travel_direction}, {time_of_day}, {time_zone})

        Creates a probability surface to predict the sales potential of an
        area based on distance and an attractiveness factor.The Huff Model can
        be for the following:

        * Estimate market potential.

        * Define and analyze market potential.

        * Assess economic impact of a new site location.

        * Forecast sales and potential of existing stores and outlets.

        * Assess the impact of competitive and environmental changes on outlet
        performance.

     INPUTS:
      in_facility_features (Feature Layer):
          An input point feature layer representing existing facility locations.
          It is the first feature from the layer, or the feature selected when a
          selection is available.
      facility_id_field (Field):
          A unique ID field for existing facilities.
      in_candidate_features (Feature Layer):
          An input point feature layer representing new candidate facility
          locations. It is the first feature from the layer or the feature
          selected when a selection is available.
      candidate_id_field (Field):
          A unique ID field for candidate facilities.
      in_sales_potential_features (Feature Layer):
          An input point or polygon feature layer used to calculate the sales
          potential. It is either all features from a layer or only selected
          features when a selection is available.
      sales_potential_id_field (Field):
          A unique ID field for sales potential features.
      sales_potential_field (Field):
          The field containing the values that will be used to calculate the
          sales potential.
      attractiveness_variables (Value Table):
          The attribute fields that indicate the attractiveness of each
          competitor. In many cases, the size of the facility is used as a
          substitute for attractiveness and will be a multivalue table. An
          additional attractiveness variable is needed. The attractiveness
          field must be present in the existing facilities (competitors) and the
          candidate facilities layer.

          * existing_facilities_value-Numeric field in the in_facility_features
          parameter layer that represents attractiveness.

          * candidates_location_value-Numeric field in the in_candidate_features
          parameter layer that matches the attractiveness value from the
          in_facility_features parameter layer. Distance does not require a
          matching field.

          * exponent-The value that determines how much of a factor the variable
          is to the attractiveness value. The default value is 1.
      distance_exponent (Double):
          The distance exponent is generally a negative number because
          attractiveness decreases when distance increases. The default value is
          -1.5.
      distance_type {String}:
          The type of distance, based on method of travel, that will be used.
          The default value is Straight Line.
      distance_units {String}:
          The distance-measuring units to be used when calculating distance.
      travel_direction {String}:
          Specifies the direction of travel that will be used between stores
          and sales potential features.

          * TOWARD_STORES-The direction of travel will be from sales potential
          features to stores. This is the default.

          * AWAY_FROM_STORES-The direction of travel will be from stores to
          sales potential features.
      time_of_day {Date}:
          The time and date that will be used when calculating distance.
      time_zone {String}:
          Specifies the time zone that will be used for the Time of Day
          parameter.

          * TIME_ZONE_AT_LOCATION-The time zone in which the territories are
          located will be used. This is the default.

          * UTC-Coordinated universal time (UTC) will be used.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class that will contain the tool results,
          representing the probability of sales.
      out_distance_matrix {Table}:
          The name and location of the matrix table of distance calculations.
          The IDs for the Input Facilitates Features and Input Candidate
          Features parameters must be unique."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.HuffModel_ba(*gp_fixargs((in_facility_features, facility_id_field, in_candidate_features, candidate_id_field, in_sales_potential_features, sales_potential_id_field, sales_potential_field, out_feature_class, attractiveness_variables, distance_exponent, distance_type, distance_units, out_distance_matrix, travel_direction, time_of_day, time_zone), True)))
        return retval
    except Exception as e:
        raise e


# Reports toolset
@gptooldoc('SummaryReports_ba', None)
def SummaryReports(in_features=None, report_templates=None, reports_folder=None, summarization_options=None, single_report=None, formats=None, store_id_field=None, store_name_field=None, store_address_field=None, store_latitude_field=None, store_longitude_field=None, ring_id_field=None, area_description_field=None, title=None, subtitle=None):
    """SummaryReports_ba(in_features, report_templates;report_templates..., reports_folder, {summarization_options}, {single_report}, {formats;formats...}, {store_id_field}, {store_name_field}, {store_address_field}, {store_latitude_field}, {store_longitude_field}, {ring_id_field}, {area_description_field}, {title}, {subtitle})

        Populates and creates demographic style summary reports for any
        boundary layer using Esri report templates.

     INPUTS:
      in_features (Feature Layer):
          The boundary layer containing one or more polygons that will be used
          to create reports.
      report_templates (String):
          One or more report templates that will be used to create the summary
          report. You must be signed in to ArcGIS Online or have Business
          Analyst Data installed.
      reports_folder (Folder):
          The output location where the summary reports will be saved.
      summarization_options {String}:
          Specifies how the data will be displayed in a report.

          * INDIVIDUAL_FEATURES-Returns selected report templates for each
          individual trade area polygon. This is the default.

          * WHOLE_LAYER-Returns selected report templates representing only the
          full extent of the trade area.

          * BOTH_FEATURES_AND_LAYER-Returns selected report templates for both
          individual features and the whole layer.
      single_report {Boolean}:
          Specifies whether a single output will be generated or if a separate
          file will be generated for each report.

          * CREATE_SINGLE_REPORT-All reports will be combined into a single
          output.

          * CREATE_REPORT_PER_TEMPLATE-A separate file will be generated for
          each selected report. This is the default.
      formats {String}:
          The report output format. The default value is PDF.
      store_id_field {Field}:
          The field that will be used to group data for each site in output
          reports. These field values are not displayed in the header.
      store_name_field {Field}:
          The field values that will be displayed in the output report headers
          that identify the site corresponding to each polygon's data.
      store_address_field {Field}:
          The store address associated with each trade area.
      store_latitude_field {Field}:
          The field that will contain the latitude coordinates (y field).
      store_longitude_field {Field}:
          The field that will contain the longitude coordinates (x field).
      ring_id_field {Field}:
          The field that will control the presentation order of data for inputs
          with multiple polygons per site.
      area_description_field {Field}:
          The field that will be displayed as the output template header with
          values corresponding to each input polygons' data.
      title {String}:
          The title on the report header.
      subtitle {String}:
          The subtitle on the report header. The default value is Prepared by
          Business Analyst for ArcGIS Pro."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummaryReports_ba(*gp_fixargs((in_features, report_templates, reports_folder, summarization_options, single_report, formats, store_id_field, store_name_field, store_address_field, store_latitude_field, store_longitude_field, ring_id_field, area_description_field, title, subtitle), True)))
        return retval
    except Exception as e:
        raise e


# Suitability Analysis toolset
@gptooldoc('AddFieldBasedSuitabilityCriteria_ba', None)
def AddFieldBasedSuitabilityCriteria(in_analysis_layer=None, fields=None):
    """AddFieldBasedSuitabilityCriteria_ba(in_analysis_layer, fields;fields...)

        Adds criteria based on the numerical fields existing in the input
        layer.

     INPUTS:
      in_analysis_layer (Feature Layer):
          The Suitability Analysis layer that will be used in the analysis.
      fields (Field):
          The numeric fields from which the suitability criteria will be
          determined."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddFieldBasedSuitabilityCriteria_ba(*gp_fixargs((in_analysis_layer, fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddPointLayerBasedSuitabilityCriteria_ba', None)
def AddPointLayerBasedSuitabilityCriteria(in_analysis_layer=None, site_layer_id_field=None, in_point_features=None, criteria_type=None, distance_type=None, units=None, in_site_centers_features=None, site_centers_id_field=None, weight_field=None, statistics_type=None, cutoff_distance=None):
    """AddPointLayerBasedSuitabilityCriteria_ba(in_analysis_layer, site_layer_id_field, in_point_features, criteria_type, {distance_type}, {units}, {in_site_centers_features}, {site_centers_id_field}, weight_field, {statistics_type}, {cutoff_distance})

        Adds criteria based on spatial relationships between the input layer
        and a given point layer.

     INPUTS:
      in_analysis_layer (Feature Layer):
          The Suitability Analysis layer that will be used in the analysis.
      site_layer_id_field (Field):
          A field containing unique values for each record within the
          Suitability Analysis layer.
      in_point_features (Feature Layer):
          The layer containing point locations to be added as criteria based on
          spatial relationship to the Suitability Analysis layer.
      criteria_type (String):
          Defines the type of spatial relationship to be used as criteria.

          * COUNT-A count of points that fall within each Suitability Analysis
          layer polygon. This is the default.

          * WEIGHT-Calculates field-weighted criteria of points that fall within
          each Suitability Analysis polygon based on the user-selected
          statistical type.

          * MINIMAL_DISTANCE-Adds distance from the closest point to each of the
          Suitability Analysis layer centroids as criteria.
      distance_type {String}:
          Defines how minimal distance is calculated based on method of travel.
      units {String}:
          Defines the type of distance measuring units to be used when
          calculating minimal distance.
      in_site_centers_features {Feature Layer}:
          The point layer that will be used as site centers. This point layer
          will replace default polygon centroids of the Suitability Analysis
          layer.
      site_centers_id_field {Field}:
          A field existing within the in_site_centers_features parameter that
          uniquely identifies each record.
      weight_field (Field):
          Numeric fields that exist within a point layer that can be selected
          for weighting.
      statistics_type {String}:
          The type of statistical operation to be applied to the weighted field.

          * SUM-Calculates the total of the field values in each point feature.

          * AVE-Determines the average field value in each point feature.

          * STD_DEV-Calculates the standard deviation of the field values in
          each point feature.

          * MIN-Determines the smallest field value in each point feature.

          * MAX-Determines the largest field value in each point feature.
      cutoff_distance {Double}:
          The distance beyond which points will not be considered in the
          calculation."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddPointLayerBasedSuitabilityCriteria_ba(*gp_fixargs((in_analysis_layer, site_layer_id_field, in_point_features, criteria_type, distance_type, units, in_site_centers_features, site_centers_id_field, weight_field, statistics_type, cutoff_distance), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddVariableBasedSuitabilityCriteria_ba', None)
def AddVariableBasedSuitabilityCriteria(in_analysis_layer=None, variables=None):
    """AddVariableBasedSuitabilityCriteria_ba(in_analysis_layer, variables;variables...)

        Adds criteria based on the values calculated for the input layer using
        the Enrich Layer tool.

     INPUTS:
      in_analysis_layer (Feature Layer):
          The Suitability Analysis layer that will be used in the analysis.
      variables (String):
          The variables from which the suitability criteria will be determined."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddVariableBasedSuitabilityCriteria_ba(*gp_fixargs((in_analysis_layer, variables), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CalculateSuitabilityScore_ba', None)
def CalculateSuitabilityScore(in_analysis_layer=None):
    """CalculateSuitabilityScore_ba(in_analysis_layer)

        Calculates or recalculates a suitability score.

     INPUTS:
      in_analysis_layer (Feature Layer):
          The Suitability Analysis Layer that will be used in the analysis."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateSuitabilityScore_ba(*gp_fixargs((in_analysis_layer,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MakeSuitabilityAnalysisLayer_ba', None)
def MakeSuitabilityAnalysisLayer(in_features=None, layer_name=None):
    """MakeSuitabilityAnalysisLayer_ba(in_features, layer_name)

        Creates a Suitability Analysis layer for a given input site's
        polygonal layer.

     INPUTS:
      in_features (Feature Layer):
          The feature layer that will be used in the creation of the Suitability
          Analysis layer.
      layer_name (String):
          The name of the output Suitability Analysis layer to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeSuitabilityAnalysisLayer_ba(*gp_fixargs((in_features, layer_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveSuitabilityCriteria_ba', None)
def RemoveSuitabilityCriteria(in_analysis_layer=None, drop_criteria=None):
    """RemoveSuitabilityCriteria_ba(in_analysis_layer, drop_criteria;drop_criteria...)

        Removes criteria from a suitability analysis layer.

     INPUTS:
      in_analysis_layer (Feature Layer):
          The suitability analysis layer from which criteria will be removed.
      drop_criteria (String):
          A list of criteria to be removed from a suitability analysis layer."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveSuitabilityCriteria_ba(*gp_fixargs((in_analysis_layer, drop_criteria), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetCriteriaProperties_ba', None)
def SetCriteriaProperties(in_analysis_layer=None, criteria_properties=None):
    """SetCriteriaProperties_ba(in_analysis_layer, criteria_properties;criteria_properties...)

        Define parameters for criteria.

     INPUTS:
      in_analysis_layer (Feature Layer):
          The Suitability Analysis layer that will be used in the analysis.
      criteria_properties (Value Table):
          The input features that will be used to set up your criteria
          properties.

          * criterion-The field, point, or variable that will be used to
          calculate your suitability score.

          * title-The name of your criteria.

          * weight-The influence a criteria value has on the overall suitability
          score. The number must be greater than or equal to 0.

          * influence-Can be positive, inverse, or ideal. An example of a
          positive influence is as follows: You want a site to score higher if
          it has a greater number of households holding graduate or professional
          degrees. An example of an inverse influence is as follows: A lower
          median home value is more desirable as it is indicative of greater
          home affordability. An example of an ideal influence would be a search
          for areas within a range of values.

          * POSITIVE-The higher the criteria value, the higher the suitability
          score.

          * INVERSE-The lower the criteria value, the higher the suitability
          score.

          * IDEAL-The closer to the ideal value, the higher the score.

          * ideal_value-The closer the criteria value is to the ideal_value, the
          higher the suitability score.

          * minimum_value-A numeric value that sets a hard limit for the
          criteria lower bound.

          * maximum_value-A numeric value that sets a hard limit for the
          criteria upper bound.

          * enabled-Check to include the criteria in the final suitability
          score."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetCriteriaProperties_ba(*gp_fixargs((in_analysis_layer, criteria_properties), True)))
        return retval
    except Exception as e:
        raise e


# Trade Areas toolset
@gptooldoc('CustomerDerivedTA_ba', None)
def CustomerDerivedTA(in_stores_layer=None, store_id_field=None, in_customers_layer=None, link_field=None, out_feature_class=None, method=None, rings=None, customer_aggregation_type=None, customer_weight_field=None, exclude_outlying_customers=None, cutoff_distance=None, dissolve_option=None, use_customer_centroids=None):
    """CustomerDerivedTA_ba(in_stores_layer, store_id_field, in_customers_layer, link_field, out_feature_class, method, rings;rings..., customer_aggregation_type, {customer_weight_field}, {exclude_outlying_customers}, {cutoff_distance}, {dissolve_option}, {use_customer_centroids})

        Creates trade areas around stores based on the number of customers or
        volume attribute of each customer.

     INPUTS:
      in_stores_layer (Feature Layer):
          Input point layer representing store or facility locations.
      store_id_field (Field):
          Unique ID representing a store or facility location.
      in_customers_layer (Feature Layer):
          Input point layer representing customers or patrons.
      link_field (Field):
          An ID used to assign individual customers to stores.
      method (String):
          The type of customer-derived trade area to be generated.

          * SIMPLE-Creates a generalized trade area based on the percentages of
          customers corresponding to each store.

          * AMOEBA-Connects points representing the boundary of the polygon
          trade area using natural curvature.

          * DETAILED-Connects points representing the boundary of the polygon
          trade area using straight lines.

          * DETAILED_WITH_SMOOTHING-Connects points representing the boundary of
          the polygon trade area with smoothed curves using cubic splines. This
          approach takes into account the shape and pattern of the customer
          distributions. This is the default.
      rings (Double):
          One or more values representing the percentage of customers-for
          example, total count or a customer attribute and total sales assigned
          to each store. Each value represents one trade area polygon.
      customer_aggregation_type (String):
          The type of aggregation.

          * COUNT-Calculates percentage-based trade areas using the geographic
          locations of customers. This is the default.

          * WEIGHT-Calculates percentage-based trade areas using a customer
          attribute-for example, Sales.
      customer_weight_field {Field}:
          The field used to calculate the trade areas. This is based on either
          the number of customers (count) or the calculated weighted value
          assigned to each customer.
      exclude_outlying_customers {Boolean}:
          Provides an option to exclude outlying customers from the trade area
          creation process.

          * EXCLUDE_OUTLIERS-Excludes outlying customers.

          * ALL_POINTS-Considers all customers. This is the default.
      cutoff_distance {Linear Unit}:
          The distance beyond which customers will be considered outliers, and
          therefore excluded from consideration during trade area creation.
      dissolve_option {String}:
          Creates polygons of the entire area or splits the polygons into
          individual features.

          * OVERLAP-Creates output polygons where each feature begins at zero
          and grows to satisfy the desired percentage of customers. For example,
          if you request a trade area of 50 percent and 70 percent of your
          customers, one polygon will be generated to include 0 to 50 percent
          and a second polygon will include all 0 to 70 percent of customers.
          This is the default.

          * SPLIT-Creates output polygons for individual features based on the
          requested percentage breaks. For example, if you request a trade area
          of 50 percent and 70 percent of your customers, one polygon will be
          generated to include 0 to 50 percent and a second polygon will include
          50 to 70 percent of customers.
      use_customer_centroids {Boolean}:
          Locates the center of your customer area and calculates trade areas
          outward from this point.

          * USE_CENTROIDS-Uses centroid of customer points to calculate trade
          areas.

          * USE_STORES-Uses store location as the starting point to calculate
          trade areas. This is the default.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output trade area feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CustomerDerivedTA_ba(*gp_fixargs((in_stores_layer, store_id_field, in_customers_layer, link_field, out_feature_class, method, rings, customer_aggregation_type, customer_weight_field, exclude_outlying_customers, cutoff_distance, dissolve_option, use_customer_centroids), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateDriveTimeTradeArea_ba', None)
def GenerateDriveTimeTradeArea(in_features=None, out_feature_class=None, distance_type=None, distances=None, units=None, id_field=None, dissolve_option=None, remove_overlap=None, travel_direction=None, time_of_day=None, time_zone=None, search_tolerance=None, polygon_detail=None):
    """GenerateDriveTimeTradeArea_ba(in_features, out_feature_class, distance_type, distances;distances..., {units}, {id_field}, {dissolve_option}, {remove_overlap}, {travel_direction}, {time_of_day}, {time_zone}, {search_tolerance}, {polygon_detail})

        Creates a feature class of trade areas, based on travel time and
        distance, around point features.You can create drive time rings that
        are nonoverlapping, and use
        various travel modes.

     INPUTS:
      in_features (Feature Layer):
          The input point feature layer.
      distance_type (String):
          Defines how the drive time is calculated based on method of travel.
      distances (Double):
          The distances that will be used for drive time calculations.
      units {String}:
          The units that will be used for the distance values. The default
          value is miles.
      id_field {Field}:
          A unique ID field for existing facilities.
      dissolve_option {String}:
          Specifies whether overlapping or nonoverlapping service areas for a
          single location will be used when multiple distances are specified.

          * OVERLAP-Each polygon will include the area reachable from the
          facility up to the distance value. This is the default.

          * SPLIT-Each polygon will include only the area between consecutive
          distance values.
      remove_overlap {Boolean}:
          Specifies whether overlapping concentric rings will be created or
          overlap will be removed from multiple locations in relation to one
          another.

          * REMOVE_OVERLAP-Polygons will be split and the overlap between output
          features will be removed.

          * KEEP_OVERLAP-Output features will be created with overlap. This is
          the default.
      travel_direction {String}:
          Specifies the direction of travel that will be used between stores
          and customers.

          * TOWARD_STORES-The direction of travel will be from customers to
          stores. This is the default.

          * AWAY_FROM_STORES-The direction of travel will be from stores to
          customers.
      time_of_day {Date}:
          The time and date that will be used when calculating distance.
      time_zone {String}:
          Specifies the time zone that will be used for the Time of Day
          parameter.

          * TIME_ZONE_AT_LOCATION-The time zone in which the territories are
          located will be used. This is the default.

          * UTC-Coordinated universal time (UTC) will be used.
      search_tolerance {Linear Unit}:
          The maximum distance that input points can be from the network.
          Points located beyond the search tolerance will be excluded from
          processing.The parameter requires a distance value and units for the
          tolerance.
          The default value is 5000 meters.
      polygon_detail {String}:
          Specifies the level of detail that will be used for the output drive
          time polygons.

          * STANDARD-Polygons with a standard level of detail will be created.
          This is the default.

          * GENERALIZED-Generalized polygons will be created using the hierarchy
          present in the network data source to produce results quickly.

          * HIGH-Polygons with a high level of detail will be created for
          applications in which very precise results are important.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class containing the drive time polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateDriveTimeTradeArea_ba(*gp_fixargs((in_features, out_feature_class, distance_type, distances, units, id_field, dissolve_option, remove_overlap, travel_direction, time_of_day, time_zone, search_tolerance, polygon_detail), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateGeographiesFromOverlay_ba', None)
def GenerateGeographiesFromOverlay(geography_level=None, in_features=None, id_field=None, out_feature_class=None, overlap_type=None, ratios=None):
    """GenerateGeographiesFromOverlay_ba(geography_level, in_features, id_field, out_feature_class, {overlap_type}, {ratios})

        Generates trade areas from the features of an input standard geography
        level that has a specified spatial relationship with the input.

     INPUTS:
      geography_level (String):
          The geography level that will be used to define the trade area.
      in_features (Feature Layer):
          The features used to extract the standard geography level features by
          the specified spatial relationship. It can be either all features from
          the layer or only those selected once a selection is available.
      id_field (Field):
          The field used to identify the input_features parameter-for example,
          the IDs of drive time polygons.
      overlap_type {String}:
          Specifies how the subgeography will be selected from the boundary
          layer.

          * INTERSECT-If any of the subgeography features touch or intersect the
          boundary layer, they will be included in the output layer. This is the
          default.

          * CENTROID_WITHIN-If the centroids of any of the subgeography features
          are contained within the boundary layer, they will be included in the
          output layer.

          * COMPLETELY_WITHIN-Only the features of the subgeography layer that
          are completely contained within the boundary layer will be included in
          the output layer.
      ratios {String}:
          Specifies the ratios to be calculated.

          * NO_RATIOS-No ratios will be implemented. This is the default.

          * AREA_ONLY-Only the ratios within the portion (area) of the standard
          geography level that intersects an input feature will be implemented.

          * ALL_RATIOS-All available ratios will be implemented. This option is
          not available when using online data.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature containing the trade area."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateGeographiesFromOverlay_ba(*gp_fixargs((geography_level, in_features, id_field, out_feature_class, overlap_type, ratios), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateTradeAreaRings_ba', None)
def GenerateTradeAreaRings(in_features=None, out_feature_class=None, radii=None, units=None, id_field=None, remove_overlap=None):
    """GenerateTradeAreaRings_ba(in_features, out_feature_class, radii;radii..., {units}, {id_field}, {remove_overlap})

        Creates rings around point locations.

     INPUTS:
      in_features (Feature Layer):
          The input features containing the center points for the rings.
      radii (Double):
          The distances, in ascending size, used to create rings around the
          input features.
      units {String}:
          The linear unit to be used with the distance values.

          * MILES-The distance unit is miles. This is the default.

          * YARDS-The distance unit is yards.

          * FEET-The distance unit is feet.

          * KILOMETERS-The distance unit is kilometers.

          * METERS-The distance unit is meters.
      id_field {Field}:
          A unique ID field in the ring center layer.
      remove_overlap {Boolean}:
          Creates overlapping concentric rings or removes overlap.

          * REMOVE_OVERLAP-Thiessen polygons are used to remove overlap between
          output ring polygons.

          * KEEP_OVERLAP-Output ring features are created with overlap. This is
          the default.

     OUTPUTS:
      out_feature_class (Feature Class):
          The feature class that will contain the output ring features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateTradeAreaRings_ba(*gp_fixargs((in_features, out_feature_class, radii, units, id_field, remove_overlap), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StandardGeographyTA_ba', None)
def StandardGeographyTA(geography_level=None, out_feature_class=None, input_type=None, in_ids_table=None, geography_key_field=None, ids_list=None, summarize_duplicates=None, group_field=None, dissolve_output=None):
    """StandardGeographyTA_ba(geography_level, out_feature_class, {input_type}, {in_ids_table}, {geography_key_field}, {ids_list}, {summarize_duplicates}, {group_field}, {dissolve_output})

        Creates trade areas based on predefined named statistical areas. This
        tool does not consume credits.Standard geographies are trade areas
        based on standardized
        administrative boundaries. In the United States this includes layers
        such as states, counties, tracts, ZIP Codes, block groups, census
        tracts, core-based statistical areas (CBSA), designated market areas
        (DMA), or places. Each country dataset offers administrative
        boundaries that can vary. Individual trade areas are created for each
        unique geography (for example, each state, each ZIP Code) that you
        select. One layer can contain several trade areas, such as one whole
        layer containing a collection of counties.

     INPUTS:
      geography_level (String):
          Geography level that will be used to define your trade area.
      input_type {String}:
          List or Table of Geography IDs.

          * TABLE-Input IDs from a table.

          * LIST-Input IDs from a list. This is the default.
      in_ids_table {Table View}:
          Input table with IDs used to select geographies that will define your
          trade area.
      geography_key_field {Field}:
          Field within Geography IDs Table that identifies records to include
          in the output.
      ids_list {String}:
          List of comma-separated geography IDs.
      summarize_duplicates {Boolean}:
          Defines how to handle duplicate fields in the table containing
          matching geographic IDs.

          * SUMMARIZE_DUPLICATES-Summarizes the numeric fields for all duplicate
          records.

          * USE_FIRST-Appends the data of the first record and ignores any
          others. This is the default.
      group_field {Field}:
          Field that is used to perform a group by operation.
      dissolve_output {Boolean}:
          Dissolves the output based on the selected group_field.

          * DISSOLVE-Dissolves the output.

          * DONT_DISSOLVE-Does not dissolve the output. This is the default.

     OUTPUTS:
      out_feature_class (Feature Class):
          Output feature containing your trade area."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StandardGeographyTA_ba(*gp_fixargs((geography_level, out_feature_class, input_type, in_ids_table, geography_key_field, ids_list, summarize_duplicates, group_field, dissolve_output), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject