#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from __future__ import print_function

import os.path
import types

import arcgisscripting
from arcpy import env, gp

from . import Utils



useLocalFunctions = True

def SetUseLocalFunctions(value):
  global useLocalFunctions
  useLocalFunctions=value

def tryLocalFunction(*args):
  """If it returns None, no local function implementation is avail,
     otherwise it returns a Raster object
  """
  assert isinstance(args, tuple)
  assert len(args) >= 1

  canUse = True # env.outputCoordinateSystem is None
  canUse = canUse and env.mask is None

  if useLocalFunctions and canUse:
    if arcgisscripting._hasLocalFunctionRasterImplementation(args[0]):
      # 0: the operation name
      # 1: a scratch name already reserved to use later in save
      flatList = [args[0], Utils.scratchName()]

      for arg in args[1:]:
        # Flatten lists. Argument can be repeatable, provided as a list.
        if isinstance(arg, list):
          flatList += arg
        else:
          flatList.append(arg)

      return Raster(flatList), True

  return None, False

class Raster(arcgisscripting.Raster):
  def __init__(self, in_raster, is_multidimensional=False):
    """Raster(in_raster, {is_multidimensional})\

    Create a Raster object.

    Arguments:
      in_raster -- Name of raster
      is_multidimensional -- Determines whether the input raster is multidimensional or not
    "
    """
    super().__init__()

  def __new__(cls, in_raster, is_multidimensional=False):
    return super().__new__(cls, in_raster, is_multidimensional)

  def getVariableAttributes(self, variable_name):
    """variableAttributes(self, variable_name)

    Returns the attribute information of a variable, e.g., description, unit, etc.
      Parameters:
         variable_name(String): the name of the variable
      Returns:
         out_variable_attributes(Dict) :the attribute information of the given variable.

    """

    return super().getVariableAttributes(variable_name)

  def getDimensionNames(self, variable_name):
    """dimensionNames(self, variable_name)

    Returns a list of the dimension names that the variable contains.
       Parameters:
         variable_name(String): the name of the variable
       Returns:
          out_dimension_names(List) :the dimension names that the given variable contains

    """

    return super().getDimensionNames(variable_name)

  def getDimensionAttributes(self, variable_name, dimension_name):
    """dimensionAttributes(self, variable_name, dimension_name)

    Returns the attribute information of a dimension within a variable, e.g., min value, max value, unit, etc.
      Parameters:
         variable_name(String): the name of the variable
         dimension_name(String): the name of the dimension
      Returns:
         out_dimension_attributes(Dict):the attribute information of the given dimension within the given variable.

    """

    return super().getDimensionAttributes(variable_name, dimension_name)

  def getDimensionValues(self, variable_name, dimension_name):
    """dimensionValues(self, variable_name, dimension_name)

    Returns the dimension values of a dimension within a variable.
      Parameters:
         variable_name(String): the name of the variable
         dimension_name(String): the name of the dimension
      Returns:
         out_dimension_values(List): a list of all dimension values along the given dimension within the given variable.

    """

    return super().getDimensionValues(variable_name, dimension_name)
